//////////////////////////////////////////////////////////////////////////////////////
// File     : jpegdemo.c															//
// Function : snapshot demo application for Sensoray model 2250          	//
//////////////////////////////////////////////////////////////////////////////////////

// PAL/NTSC issue in V117
// Always call SN_SetVideoSystem before SN_SetBasicChipSettings

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include "s2250mid.h"

int main(int argc, char **argv)
{
    int res;
    char buffer[64000];
    frame_info_t fi;
    FILE *file;
    int i;
    int vsystem;
    int board;
    int num_boards;
    MIDSRAY_VIDSYS vidsys;
    // open board 0
    if( argc <2 ) {
        printf("this demo requires you to specify the video system\n");
        printf("It also uses the default S-Video port.\n");
        printf("If the image is black and white, you are using composite.\n");
        printf("Usage ./jpegdemo system\n");
        printf("      where system == 0 NTSC, system==1 PAL\n");
        return -1;
    }
    vsystem = atoi( argv[1]);
    if( vsystem == 1) {
        printf("using PAL\n");
        vidsys = MIDSRAY_VIDSYS_PAL;
    } else {
        printf("using NTSC\n");
        vidsys = MIDSRAY_VIDSYS_NTSC;
    }
    //SN_Debug(1);

    num_boards = SN_EnumBoards();
    printf("Number of boards : %i\n", num_boards);

    board = 0;
    while (1) {
        res = SN_OpenBoard(board);
        if (res == 0) break;
	board++;
	if (board >= num_boards) {
            printf("err opening board\n");
            return 0;
        }
    }
    printf("Selected board : %i\n", board);
    
    // set motion jpeg, full size, NTSC, 4MBit/s (Iframe setting N/A for MOTIONJPEG)
    SN_SetBasicChipSettings(board, MIDSRAY_ENCODE_MOTIONJPEG, 0, vidsys, 4000000, 0);
    
    // start capturing
    SN_StartStream( board);
    
    // disable avsync (recommended for motionjpeg)
    //SN_DisableAVSync(board, 1);
    // set caption( must be done after start stream)
    i = 0;
    while( i < 2)
    {
        res = SN_GetOneFrame( board, buffer, 64000, &fi);
        if( res == 0)
            break;
        i++;
        usleep(1);
    }

    if( res != 0)
    {
        printf("failed to get snapshot.  make sure input connected\n");
        SN_StopStream(board);
        SN_CloseBoard(board);
        return 0;
    }
    else
    {
        printf("snapshot taken after %d ms\n", i);
    }

    file = fopen( "snapshot.jpg", "wb");
    fwrite( buffer, 1, fi.data_length, file );
    fclose(file);
    printf("Snapshot complete: wrote %d bytes to %s\n", fi.data_length, "snapshot.jpg");
    SN_StopStream(board);
    SN_CloseBoard(board);
    return 0;
}
